@@ -21,11 +21,11 @@ test_that("compareR function tests", {
   expect_equal(output1$acc$glob.p.value, 0.04811515, tolerance = 1e-06)
   expect_equal(output1$acc$glob.p.adj, 0.1443455, tolerance = 1e-06)
   expect_equal(output1$acc$sens.test.stat, 3.2, tolerance = 1e-06)
-  expect_equal(output1$acc$sens.p.value, 0.07363827, tolerance = 1e-06)
-  expect_equal(output1$acc$sens.p.adj, 0.1472765, tolerance = 1e-06)
+  expect_equal(output1$acc$sens.p.value, as.double(NA), tolerance = 1e-06)
+  expect_equal(output1$acc$sens.p.adj, as.double(NA), tolerance = 1e-06)
   expect_equal(output1$acc$spec.test.stat, 0, tolerance = 1e-06)
-  expect_equal(output1$acc$spec.p.value, 1, tolerance = 1e-06)
-  expect_equal(output1$acc$spec.p.adj, 1, tolerance = 1e-06)
+  expect_equal(output1$acc$spec.p.value, as.double(NA), tolerance = 1e-06)
+  expect_equal(output1$acc$spec.p.adj, as.double(NA), tolerance = 1e-06)
 
   expect_type(output1$pv$predictive.values, "list")
   expect_type(output1$pv$predictive.values[[1]], "double")
@@ -77,7 +77,7 @@ test_that("compareR function tests", {
   expect_equal(output1$acc$glob.p.adj, 4.167158e-07, tolerance = 1e-06)
   expect_equal(output1$acc$sens.test.stat, 18.05, tolerance = 1e-06)
   expect_equal(output1$acc$sens.p.value, 2.151786e-05, tolerance = 1e-06)
-  expect_equal(output1$acc$sens.p.adj, 0.0001506251, tolerance = 1e-06)
+  expect_equal(output1$acc$sens.p.adj, 0.0001291072, tolerance = 1e-06)
   expect_equal(output1$acc$spec.test.stat, 8.1, tolerance = 1e-06)
   expect_equal(output1$acc$spec.p.value, 0.004426526, tolerance = 1e-06)
   expect_equal(output1$acc$spec.p.adj, 0.02213263, tolerance = 1e-06)
